########
 config
########

This module provides utilities for managing configuration settings in
Anemoi. It includes functions to load, merge, and access configurations.

By default configuration files are loaded from
``~/.config/anemoi/settings.toml``.

An override path can be specified using the environment variable
``ANEMOI_CONFIG_OVERRIDE_PATH``.

.. automodule:: anemoi.utils.config
   :members:
   :no-undoc-members:
   :show-inheritance:
